<?php
/**
 * Moon Theme Customizer.
 *
 * @package Moon
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function nq_moon_customize_register( $wp_customize ) {
	// Header section
	$wp_customize->get_section( 'header_image' )->title = esc_html__( 'Header', 'moon' );
	$wp_customize->get_section( 'header_image' )->priority = 25;
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_control( 'header_textcolor' )->section   = 'header_image';
	$wp_customize->get_control( 'header_textcolor' )->priority  = 11;
	$wp_customize->get_control( 'blogdescription' )->section    = 'header_image';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->remove_control( 'blogname' );
	$wp_customize->remove_control( 'display_header_text' );

	$wp_customize->get_section( 'colors' )->title    = esc_html__( 'Content', 'moon' );
	$wp_customize->get_section( 'colors' )->priority = 30;

	// Logo
	$wp_customize->add_setting( 'logo' , array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'logo',
			array(
				'label'    => esc_html__( 'Upload a logo', 'moon' ),
				'section'  => 'header_image',
				'settings' => 'logo',
				'priority' => 1
			)
		)
	);
	// Header background color
	$wp_customize->add_setting( 'header_bgcolor' , array(
		'default'           => '#fff',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'header_bgcolor', 
		array(
			'label'    => esc_html__( 'Background Color', 'moon' ),
			'section'  => 'header_image',
			'settings' => 'header_bgcolor',
		) ) 
	);

	// Navigation
	$wp_customize->add_setting( 'navigation_bgcolor' , array(
		'default'           => '#23282d',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'navigation_bgcolor', 
		array(
			'label'    => esc_html__( 'Navigation Background Color', 'moon' ),
			'section'  => 'header_image',
			'settings' => 'navigation_bgcolor',
			'priority' => 15,
		) ) 
	);
	$wp_customize->add_setting( 'navigation_color' , array(
		'default'           => '#eee',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'navigation_color', 
		array(
			'label'    => esc_html__( 'Navigation Color', 'moon' ),
			'section'  => 'header_image',
			'settings' => 'navigation_color',
			'priority' => 16,
		) ) 
	);
	$wp_customize->add_setting( 'header_fixed', array(
		'default'           => 0,
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 'header_fixed', array(
		'label'    => esc_html__( 'Enable Sticky Menu', 'moon' ),
		'section'  => 'header_image',
		'settings' => 'header_fixed',
		'type'     => 'checkbox',
		'priority' => 17,
	) );

	// Content background
	$wp_customize->add_setting( 'body_color' , array(
		'default'           => '#404040',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'body_color', 
		array(
			'label'    => esc_html__( 'Body Text Color', 'moon' ),
			'section'  => 'colors',
			'settings' => 'body_color',
		) ) 
	);

	// Link color
	$wp_customize->add_setting( 'link_color' , array(
		'default'           => '#868686',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'link_color', 
		array(
			'label'    => esc_html__( 'Link Color', 'moon' ),
			'section'  => 'colors',
			'settings' => 'link_color',
		) ) 
	);
	$wp_customize->add_setting( 'link_hover_color' , array(
		'default'           => '#000000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'link_hover_color', 
		array(
			'label'    => esc_html__( 'Link Hover Color', 'moon' ),
			'section'  => 'colors',
			'settings' => 'link_hover_color',
		) ) 
	);
	$wp_customize->add_setting( 'boxed', array(
		'default'           => 0,
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 'boxed', array(
		'label'      => esc_html__( 'Enable Boxed Layout', 'moon' ),
		'section'    => 'colors',
		'settings'   => 'boxed',
		'type'       => 'checkbox',
	) );
	$wp_customize->add_setting( 'content_width', array(
		'default'           => 1170,
		'transport'         => 'postMessage',
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 'content_width', array(
		'label'           => esc_html__( 'Content Width', 'moon' ),
		'description'     => esc_html__( 'Number Only (Unit: pixel)', 'moon' ),
		'section'         => 'colors',
		'settings'        => 'content_width',
		'type'            => 'text',
		'active_callback' => 'callback_boxed',
	) );
	$wp_customize->get_control( 'background_image' )->section = 'colors';
	$wp_customize->get_control( 'background_image' )->active_callback = 'callback_boxed';
	$wp_customize->get_control( 'background_image' )->priority = 20;
	$wp_customize->get_control( 'background_repeat' )->section = 'colors';
	$wp_customize->get_control( 'background_repeat' )->priority = 21;
	$wp_customize->get_control( 'background_position_x' )->section = 'colors';
	$wp_customize->get_control( 'background_position_x' )->priority = 22;
	$wp_customize->get_control( 'background_attachment' )->section = 'colors';
	$wp_customize->get_control( 'background_attachment' )->priority = 23;
	function callback_boxed( $control ) {
		if ( $control->manager->get_setting( 'boxed' )->value() == 1 ) {
			return true;
		} else {
			return false;
		}
	}

	// Blog layout
	$wp_customize->add_section( 'blog_layout' , array(
		'title'      => esc_html__( 'Blog', 'moon' ),
		'priority'   => 40,
	) );
	$wp_customize->add_setting( 'blog_layout', array(
		'default'           => '',
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 'blog_layout', array(
		'label'   => esc_html__( 'Choose Blog Layout', 'moon' ),
		'type'    => 'select',
		'section' => 'blog_layout',
		'choices' => array(
			''  => esc_html__( 'Left Sidebar', 'moon' ),
			'no-sidebar'    => esc_html__( 'No Sidebar', 'moon' ),
			'right-sidebar' => esc_html__( 'Right Sidebar', 'moon' ),
		)
	) );

	// Footer
	$wp_customize->add_section( 'footer' , array(
		'title'      => esc_html__( 'Footer', 'moon' ),
		'priority'   => 50,
	) );
	$wp_customize->add_setting( 'footer_bgcolor' , array(
		'default'           => '#000',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'footer_bgcolor', 
		array(
			'label'    => esc_html__( 'Background Color', 'moon' ),
			'section'  => 'footer',
			'settings' => 'footer_bgcolor',
		) ) 
	);
	$wp_customize->add_setting( 'footer_color' , array(
		'default'           => '#868686',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'footer_color', 
		array(
			'label'    => esc_html__( 'Color', 'moon' ),
			'section'  => 'footer',
			'settings' => 'footer_color',
		) ) 
	);
	$wp_customize->add_setting( 'footer_link_color' , array(
		'default'           => '#868686',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'footer_link_color', 
		array(
			'label'    => esc_html__( 'Link Color', 'moon' ),
			'section'  => 'footer',
			'settings' => 'footer_link_color',
		) ) 
	);
	$wp_customize->add_setting( 'footer_link_hover_color' , array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'footer_link_hover_color', 
		array(
			'label'    => esc_html__( 'Link Hover Color', 'moon' ),
			'section'  => 'footer',
			'settings' => 'footer_link_hover_color',
		) ) 
	);
	$wp_customize->add_setting( 'footer_fixed', array(
		'default'           => 1,
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 'footer_fixed', array(
		'label'    => esc_html__( 'Enable Fixed Footer', 'moon' ),
		'section'  => 'footer',
		'settings' => 'footer_fixed',
		'type'     => 'checkbox',
	) );
	$wp_customize->add_setting( 'footer_content' , array(
		'default'           => esc_html__( '(c) 2016 Moon - All Rights Reserved.', 'moon' ),
		'transport'         => 'postMessage',
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 
		new WP_Customize_Control( 
		$wp_customize, 
		'footer_content', 
		array(
			'label'    => esc_html__( 'Site Copyright', 'moon' ),
			'section'  => 'footer',
			'settings' => 'footer_content',
			'type'     => 'textarea',
		) ) 
	);
}
add_action( 'customize_register', 'nq_moon_customize_register' );

/**
 * Custom style.
 *
 * @since Moon 1.0.0
 *
 */
if ( ! function_exists( 'nq_moon_custom_css' ) ) {
	function nq_moon_custom_css( $css = array() ) {
		$bg_color          = get_theme_mod( 'background_color', 'f2f2f2' );
		$body_color        = get_theme_mod( 'body_color', '#404040' );
		$link_color        = get_theme_mod( 'link_color', '#868686' );
		$link_hover_color  = get_theme_mod( 'link_hover_color', '#000000' );

		// Header
		$header_textcolor   = get_theme_mod( 'header_textcolor', 'acacac' );
		$header_bgcolor     = get_theme_mod( 'header_bgcolor', '#fff' );
		$header_image       = get_header_image();
		$navigation_bgcolor = get_theme_mod( 'navigation_bgcolor', '#23282d' );
		$navigation_color   = get_theme_mod( 'navigation_color', '#eee' );

		// Boxed layout
		$boxed = get_theme_mod( 'boxed', 0 );
		$boxed_width = get_theme_mod( 'content_width', 1170 );

		// Foter
		$footer_bgcolor    = get_theme_mod( 'footer_bgcolor', '#000' );
		$footer_color      = get_theme_mod( 'footer_color', '#868686' );
		$footer_link_color = get_theme_mod( 'footer_link_color', '#868686' );
		$footer_link_hover = get_theme_mod( 'footer_link_hover_color', '#fff' );

		if ( $header_textcolor ) {
			$css[] = '.site-description { color: #' . esc_attr( $header_textcolor ) . '; }';
		}
		$css[] = '.site-header {';
			if ( $header_bgcolor ) {
				$css[] = 'background: ' . esc_attr( $header_bgcolor ) . ';';
			}
			if ( ! empty( $header_image ) ) {
				$css[] = '
					background-image: url( ' . esc_url( $header_image ) . ' );
					background-repeat: no-repeat;
					background-position: 50% 50%;
					background-size: cover;
				';
			}
		$css[] = '}';
		if ( $navigation_bgcolor ) {
			$css[] = '.site-navigation, #primary-menu ul { background: ' . esc_attr( $navigation_bgcolor ) . '; }';
			$css[] = '
				@media screen and (max-width: 1024px) {
					#primary-menu { background: ' . esc_attr( $navigation_bgcolor ) . '; }
				}
			';
		}
		if ( $navigation_color ) {
			$css[] = '#primary-menu li a { color: ' . esc_attr( $navigation_color ) . '; }';
		}

		// Content
		if ( $bg_color && ! $boxed ) {
			$css[] = '.site-content { background: #' . esc_attr( $bg_color ) . '; }';
		} else {
			$css[] = 'body { background: #' . esc_attr( $bg_color ) . '; }';
		}

		if ( $boxed && ! empty( $boxed_width ) ) {
			$css[] = '.boxed .wrapper, .boxed .site-footer.fixed { max-width: ' . ( int ) $boxed_width . 'px; }';
		}
		
		if ( $body_color ) {
			$css[] = 'body { color: ' . esc_attr( $body_color ) . '; }';
		}

		if ( $link_color ) {
			$css[] = 'a { color: ' . esc_attr( $link_color ) . '; }';
		}

		if ( $link_hover_color ) {
			$css[] = 'a:hover, a:active, a:focus { color: ' . esc_attr( $link_hover_color ) . '; }';
		}

		// Footer
		$css[] = '.site-footer {';
			if ( $footer_bgcolor ) {
				$css[] = 'background: ' . esc_attr( $footer_bgcolor ) . ';';
			}
			if ( $footer_color ) {
				$css[] = 'color: ' . esc_attr( $footer_color ) . ';';
			}
		$css[] = '}';

		if ( $footer_link_color ) {
			$css[] = '.site-footer a { color: ' . esc_attr( $footer_link_color ) . '; }';
		}
		if ( $footer_link_hover ) {
			$css[] = '.site-footer a:hover { color: ' . esc_attr( $footer_link_hover ) . '; }';
		}

		return implode( '', $css );
	}
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function nq_moon_customize_preview() {
	wp_enqueue_script( 'moon-customizer-preview', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '', true );
}
add_action( 'customize_preview_init', 'nq_moon_customize_preview' );
